@@ -12,10 +12,7 @@ async fn main() -> io::Result<()> {
     let src = env::args().nth(1).expect("missing src");
 
     let mut reader = File::open(src).await.map(bgzf::AsyncReader::new)?;
-
-    let stdout = io::stdout();
-    let mut writer = io::BufWriter::new(stdout);
-
+    let mut writer = io::BufWriter::new(io::stdout());
     io::copy_buf(&mut reader, &mut writer).await?;
 
     Ok(())
