@@ -1,8 +1,9 @@
 //! BGZF writer.
 
+mod builder;
 mod compression_level;
 
-pub use self::compression_level::CompressionLevel;
+pub use self::{builder::Builder, compression_level::CompressionLevel};
 
 use std::{
     cmp,
@@ -39,6 +40,11 @@ pub(crate) static BGZF_EOF: &[u8] = &[
     0x00, 0x00, 0x00, 0x00, // ISIZE = 0
 ];
 
+#[cfg(feature = "libdeflate")]
+type CompressionLevelImpl = libdeflater::CompressionLvl;
+#[cfg(not(feature = "libdeflate"))]
+type CompressionLevelImpl = flate2::Compression;
+
 /// A BZGF writer.
 ///
 /// This implements [`std::io::Write`], consuming uncompressed data and emitting compressed data.
@@ -62,12 +68,26 @@ where
 {
     inner: Option<W>,
     buf: Vec<u8>,
+    compression_level: CompressionLevelImpl,
 }
 
 impl<W> Writer<W>
 where
     W: Write,
 {
+    /// Creates a BGZF writer builder.
+    ///
+    /// # Examples
+    ///
+    /// ```
+    /// use noodles_bgzf as bgzf;
+    /// let builder = bgzf::Writer::builder(Vec::new());
+    /// let writer = builder.build();
+    /// ```
+    pub fn builder(inner: W) -> Builder<W> {
+        Builder::new(inner)
+    }
+
     /// Creates a writer with a default compression level.
     ///
     /// # Examples
@@ -77,10 +97,7 @@ where
     /// let writer = bgzf::Writer::new(Vec::new());
     /// ```
     pub fn new(inner: W) -> Self {
-        Self {
-            inner: Some(inner),
-            buf: Vec::with_capacity(block::MAX_UNCOMPRESSED_DATA_LENGTH),
-        }
+        Self::builder(inner).build()
     }
 
     /// Returns a reference to the underlying writer.
@@ -97,7 +114,7 @@ where
     }
 
     fn flush_block(&mut self) -> io::Result<()> {
-        let (cdata, crc32, r#isize) = deflate_data(&self.buf, Default::default())?;
+        let (cdata, crc32, r#isize) = deflate_data(&self.buf, self.compression_level)?;
 
         let inner = self.inner.as_mut().unwrap();
 
